==> rxmicro-annotation-processor-data-sql-0.2-sources.jar: io/rxmicro/annotation/processor/data/sql/model/VariableContext.java <==
/*
 * Copyright (c) 2020. https://rxmicro.io
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.rxmicro.annotation.processor.data.sql.model;

import static io.rxmicro.common.util.Requires.require;

/**
 * @author nedis
 * @link https://rxmicro.io
 * @since 0.1
 */
public abstract class VariableContext {

    private TableContext currentTable;

    public final TableContext getCurrentTable() {
        return require(currentTable, "Current table is not set");
    }

    public void setCurrentTable(TableContext tableContext) {
        if (this.currentTable != null) {
            throw new IllegalStateException("currentTable  already set");
        }
        this.currentTable = tableContext;
    }

    public void releaseCurrentTable() {
        currentTable = null;
    }

    /**
     * @param sequenceName - sequence name
     * @return get next sequence value expression
     * @throws UnsupportedOperationException if variable context does not support sequences
     */
    public abstract String getNextSequenceValue(String sequenceName) throws UnsupportedOperationException;
}

==> rxmicro-annotation-processor-data-sql-0.4.2-sources.jar: io/rxmicro/annotation/processor/data/sql/model/VariableContext.java <==
/*
 * Copyright (c) 2020. https://rxmicro.io
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.rxmicro.annotation.processor.data.sql.model;

import io.rxmicro.common.InvalidStateException;

import static io.rxmicro.common.util.Requires.require;

/**
 * @author nedis
 * @since 0.1
 */
public abstract class VariableContext {

    private TableContext currentTable;

    public final TableContext getCurrentTable() {
        return require(currentTable, "Current table is not set");
    }

    public void setCurrentTable(final TableContext tableContext) {
        if (this.currentTable != null) {
            throw new InvalidStateException("currentTable  already set");
        }
        this.currentTable = tableContext;
    }

    public void releaseCurrentTable() {
        currentTable = null;
    }

    /**
     * @param sequenceName - sequence name
     * @return get next sequence value expression
     * @throws UnsupportedOperationException if variable context does not support sequences
     */
    public abstract String getNextSequenceValue(String sequenceName);
}
